==> collective.contract_management-1.0b2.tar.gz: collective.contract_management-1.0b2/src/collective/contract_management/vocabularies/reminder_types.py <==
# -*- coding: utf-8 -*-

# from plone import api
from collective.contract_management import _
from plone.dexterity.interfaces import IDexterityContent
from zope.globalrequest import getRequest
from zope.interface import implementer
from zope.schema.interfaces import IVocabularyFactory
from zope.schema.vocabulary import SimpleTerm
from zope.schema.vocabulary import SimpleVocabulary


class VocabItem(object):
    def __init__(self, token, value):
        self.token = token
        self.value = value


@implementer(IVocabularyFactory)
class ReminderTypes(object):
    """
    """

    def __call__(self, context):
        # Just an example list of content for our vocabulary,
        # this can be any static or dynamic data, a catalog result for example.
        items = [
            VocabItem(u'14', _(u'14 days')),
            VocabItem(u'30', _(u'30 days')),
            VocabItem(u'60', _(u'60 days')),
            VocabItem(u'90', _(u'90 days')),
            VocabItem(u'120', _(u'120 days')),
        ]

        # Fix context if you are using the vocabulary in DataGridField.
        # See https://github.com/collective/collective.z3cform.datagridfield/issues/31:  # NOQA: 501
        if not IDexterityContent.providedBy(context):
            req = getRequest()
            context = req.PARENTS[0]

        # create a list of SimpleTerm items:
        terms = []
        for item in items:
            terms.append(
                SimpleTerm(
                    value=item.token,
                    token=str(item.token),
                    title=item.value,
                )
            )
        # Create a SimpleVocabulary from the terms list and return it:
        return SimpleVocabulary(terms)


ReminderTypesFactory = ReminderTypes()

==> collective.contract_management-2.0b7.tar.gz: collective.contract_management-2.0b7/src/collective/contract_management/vocabularies/reminder_types.py <==
# -*- coding: utf-8 -*-

# from plone import api
from collective.contract_management import _
from plone.dexterity.interfaces import IDexterityContent
from zope.globalrequest import getRequest
from zope.interface import implementer
from zope.schema.interfaces import IVocabularyFactory
from zope.schema.vocabulary import SimpleTerm, SimpleVocabulary


class VocabItem(object):
    def __init__(self, token, value):
        self.token = token
        self.value = value


@implementer(IVocabularyFactory)
class ReminderTypes(object):
    """
    """

    def __call__(self, context):
        # Just an example list of content for our vocabulary,
        # this can be any static or dynamic data, a catalog result for example.
        items = [
            VocabItem(u'14', _(u'14 days')),
            VocabItem(u'30', _(u'30 days')),
            VocabItem(u'60', _(u'60 days')),
            VocabItem(u'90', _(u'90 days')),
            VocabItem(u'120', _(u'120 days')),
        ]

        # Fix context if you are using the vocabulary in DataGridField.
        # See https://github.com/collective/collective.z3cform.datagridfield/issues/31:  # NOQA: 501
        if not IDexterityContent.providedBy(context):
            req = getRequest()
            context = req.PARENTS[0]

        # create a list of SimpleTerm items:
        terms = []
        for item in items:
            terms.append(
                SimpleTerm(
                    value=item.token,
                    token=str(item.token),
                    title=item.value,
                )
            )
        # Create a SimpleVocabulary from the terms list and return it:
        return SimpleVocabulary(terms)


ReminderTypesFactory = ReminderTypes()
